@@ -12,6 +12,11 @@ module.exports = {
       value: 'https://github.com/phonegap/phonegap-facebook-plugin.git',      
       name: 'Facebook',
       checked: false
+    },
+    {
+      value: 'todo',      
+      name: 'Username/Password',
+      checked: false
     }
     ]
   }]
